@@ -27,27 +27,35 @@ def __get_results_from_threads(running_threads):
     if running_threads:
         for thread in running_threads:
             try:
-                result = thread.join()
+                result, input_data = None, None
+                is_basic = isinstance(thread, MyBasicThread)
+                if is_basic:
+                    result = thread.join()
+                else:
+                    result, input_data = thread.join()
                 return_data = result.get_return_value()
                 error = result.get_error()
 
                 if return_data:
                     thread_results.append(return_data)
-                else:
-                    thread_results.append(error)
-                    LOGGER.error(f"{error.__class__}: Results error from {thread.name}: {error}")
+
+                if error:
+                    if is_basic:
+                        LOGGER.error(f"{error[0].__class__}: Results error from {thread.name}: {error[0]}\n")
+                    else:
+                        LOGGER.error(f"{error[0].__class__}: Results error from {thread.name} using {input_data}: {error[0]}\n")
 
             except Exception as e:
-                LOGGER.error(f"{e.__class__}: Unable to collect results from {thread.name} ({thread.__func.__name__})")
+                LOGGER.error(f"{e.__class__}: Unable to collect results from {thread.name} ({thread._func.__name__})")
 
         try:
             # Re-combine the results to return as if a single thread was used (flatten list)
             return_val = [item for sublist in thread_results for item in sublist]
-
+            LOGGER.info(f"Successfully merged results from multiple threads")
             return return_val
 
         except Exception as e:
-            LOGGER.error(f"{e.__class__}: could not process the following results:\n\t\t{thread_results}")
+            LOGGER.error(f"{e.__class__}: could not merge thread results.")
             return e
 
 
@@ -83,12 +91,19 @@ def go(func, args, arg_data_index, n_threads=0):
     running_threads = []
     data_count = len(args[arg_data_index])
 
+    if not data_count:
+        LOGGER.info(f"ReadyThready.go received no input at at the specified position ({arg_data_index}) in the "
+                    f"supplied arguments '{args}'. The function '{func.__name__}' will not be run")
+        return None
+
     # set number of threads to use: specified, CPU core count, or data count (to prevent use of excess resources)
     if n_threads == 0:
         n_threads = multiprocessing.cpu_count()
     if data_count / n_threads <= 1:
         n_threads = data_count
 
+    LOGGER.info(f"Using {n_threads} threads to run '{func.__name__}' for {data_count} input items")
+
     # split data by number of threads (works with DataFrames)
     data = __split_list(args[arg_data_index], n_threads, data_count)
 
